# Getting Help

## Documentation
Official documentation for the project and all of its features is hosted at:

https://pantab.readthedocs.io/en/latest/index.html

## Community

If you'd like to chat with the developer(s) or other users in the community, freel free to join the Gitter channel:

https://gitter.im/pantab

## Warranty / Consulting
As dictated by the license, pantab comes without warranty. innobi LLC fortunately offers consulting services and direct support for pantab and on anything which integrates Python and Tableau. Reach out to sales@innobi.io for more details.